Enum style::properties::LonghandId
[−]
[src]
pub enum LonghandId {
BackgroundColor,
BackgroundImage,
BackgroundPositionX,
BackgroundPositionY,
BackgroundRepeat,
BackgroundAttachment,
BackgroundClip,
BackgroundOrigin,
BackgroundSize,
BorderTopColor,
BorderTopStyle,
BorderTopWidth,
BorderLeftColor,
BorderLeftStyle,
BorderLeftWidth,
BorderBottomColor,
BorderBottomStyle,
BorderBottomWidth,
BorderRightColor,
BorderRightStyle,
BorderRightWidth,
BorderBlockStartColor,
BorderBlockStartStyle,
BorderBlockStartWidth,
BorderBlockEndColor,
BorderBlockEndStyle,
BorderBlockEndWidth,
BorderInlineStartColor,
BorderInlineStartStyle,
BorderInlineStartWidth,
BorderInlineEndColor,
BorderInlineEndStyle,
BorderInlineEndWidth,
BorderTopLeftRadius,
BorderTopRightRadius,
BorderBottomRightRadius,
BorderBottomLeftRadius,
BorderImageSource,
BorderImageOutset,
BorderImageRepeat,
BorderImageWidth,
BorderImageSlice,
Display,
Position,
Float,
Clear,
ServoDisplayForHypotheticalBox,
VerticalAlign,
ServoOverflowClipBox,
OverflowX,
OverflowY,
TransitionDuration,
TransitionTimingFunction,
TransitionProperty,
TransitionDelay,
AnimationName,
AnimationDuration,
AnimationTimingFunction,
AnimationIterationCount,
AnimationDirection,
AnimationPlayState,
AnimationFillMode,
AnimationDelay,
Transform,
Perspective,
PerspectiveOrigin,
BackfaceVisibility,
TransformStyle,
TransformOrigin,
Color,
ColumnWidth,
ColumnCount,
ColumnGap,
Content,
CounterIncrement,
CounterReset,
Opacity,
BoxShadow,
Clip,
Filter,
MixBlendMode,
FontFamily,
FontStyle,
FontVariantCaps,
FontWeight,
FontSize,
FontStretch,
Visibility,
WritingMode,
Direction,
ImageRendering,
BorderCollapse,
EmptyCells,
CaptionSide,
BorderSpacing,
LineHeight,
TextTransform,
TextIndent,
OverflowWrap,
WordBreak,
TextJustify,
TextAlign,
LetterSpacing,
WordSpacing,
ServoTextDecorationsInEffect,
WhiteSpace,
TextShadow,
TextRendering,
ListStylePosition,
ListStyleType,
ListStyleImage,
Quotes,
MarginTop,
MarginLeft,
MarginBottom,
MarginRight,
MarginBlockStart,
MarginBlockEnd,
MarginInlineStart,
MarginInlineEnd,
OutlineColor,
OutlineStyle,
OutlineWidth,
OutlineOffset,
PaddingTop,
PaddingLeft,
PaddingBottom,
PaddingRight,
PaddingBlockStart,
PaddingBlockEnd,
PaddingInlineStart,
PaddingInlineEnd,
Cursor,
PointerEvents,
Top,
Left,
Bottom,
Right,
OffsetBlockStart,
OffsetBlockEnd,
OffsetInlineStart,
OffsetInlineEnd,
ZIndex,
FlexDirection,
FlexWrap,
JustifyContent,
AlignContent,
AlignItems,
FlexGrow,
FlexShrink,
AlignSelf,
Order,
FlexBasis,
Width,
MinWidth,
MaxWidth,
Height,
MinHeight,
MaxHeight,
BlockSize,
MinBlockSize,
MaxBlockSize,
InlineSize,
MinInlineSize,
MaxInlineSize,
BoxSizing,
TableLayout,
TextOverflow,
UnicodeBidi,
TextDecorationLine,
}An identifier for a given longhand property.
Variants
BackgroundColorbackground-color
BackgroundImagebackground-image
BackgroundPositionXbackground-position-x
BackgroundPositionYbackground-position-y
BackgroundRepeatbackground-repeat
BackgroundAttachmentbackground-attachment
BackgroundClipbackground-clip
BackgroundOriginbackground-origin
BackgroundSizebackground-size
BorderTopColorborder-top-color
BorderTopStyleborder-top-style
BorderTopWidthborder-top-width
BorderLeftColorborder-left-color
BorderLeftStyleborder-left-style
BorderLeftWidthborder-left-width
BorderBottomColorborder-bottom-color
BorderBottomStyleborder-bottom-style
BorderBottomWidthborder-bottom-width
BorderRightColorborder-right-color
BorderRightStyleborder-right-style
BorderRightWidthborder-right-width
BorderBlockStartColorborder-block-start-color
BorderBlockStartStyleborder-block-start-style
BorderBlockStartWidthborder-block-start-width
BorderBlockEndColorborder-block-end-color
BorderBlockEndStyleborder-block-end-style
BorderBlockEndWidthborder-block-end-width
BorderInlineStartColorborder-inline-start-color
BorderInlineStartStyleborder-inline-start-style
BorderInlineStartWidthborder-inline-start-width
BorderInlineEndColorborder-inline-end-color
BorderInlineEndStyleborder-inline-end-style
BorderInlineEndWidthborder-inline-end-width
BorderTopLeftRadiusborder-top-left-radius
BorderTopRightRadiusborder-top-right-radius
BorderBottomRightRadiusborder-bottom-right-radius
BorderBottomLeftRadiusborder-bottom-left-radius
BorderImageSourceborder-image-source
BorderImageOutsetborder-image-outset
BorderImageRepeatborder-image-repeat
BorderImageWidthborder-image-width
BorderImageSliceborder-image-slice
Displaydisplay
Positionposition
Floatfloat
Clearclear
ServoDisplayForHypotheticalBox-servo-display-for-hypothetical-box
VerticalAlignvertical-align
ServoOverflowClipBox-servo-overflow-clip-box
OverflowXoverflow-x
OverflowYoverflow-y
TransitionDurationtransition-duration
TransitionTimingFunctiontransition-timing-function
TransitionPropertytransition-property
TransitionDelaytransition-delay
AnimationNameanimation-name
AnimationDurationanimation-duration
AnimationTimingFunctionanimation-timing-function
AnimationIterationCountanimation-iteration-count
AnimationDirectionanimation-direction
AnimationPlayStateanimation-play-state
AnimationFillModeanimation-fill-mode
AnimationDelayanimation-delay
Transformtransform
Perspectiveperspective
PerspectiveOriginperspective-origin
BackfaceVisibilitybackface-visibility
TransformStyletransform-style
TransformOrigintransform-origin
Colorcolor
ColumnWidthcolumn-width
ColumnCountcolumn-count
ColumnGapcolumn-gap
Contentcontent
CounterIncrementcounter-increment
CounterResetcounter-reset
Opacityopacity
BoxShadowbox-shadow
Clipclip
Filterfilter
MixBlendModemix-blend-mode
FontFamilyfont-family
FontStylefont-style
FontVariantCapsfont-variant-caps
FontWeightfont-weight
FontSizefont-size
FontStretchfont-stretch
Visibilityvisibility
WritingModewriting-mode
Directiondirection
ImageRenderingimage-rendering
BorderCollapseborder-collapse
EmptyCellsempty-cells
CaptionSidecaption-side
BorderSpacingborder-spacing
LineHeightline-height
TextTransformtext-transform
TextIndenttext-indent
OverflowWrapoverflow-wrap
WordBreakword-break
TextJustifytext-justify
TextAligntext-align
LetterSpacingletter-spacing
WordSpacingword-spacing
ServoTextDecorationsInEffect-servo-text-decorations-in-effect
WhiteSpacewhite-space
TextShadowtext-shadow
TextRenderingtext-rendering
ListStylePositionlist-style-position
ListStyleTypelist-style-type
ListStyleImagelist-style-image
Quotesquotes
MarginTopmargin-top
MarginLeftmargin-left
MarginBottommargin-bottom
MarginRightmargin-right
MarginBlockStartmargin-block-start
MarginBlockEndmargin-block-end
MarginInlineStartmargin-inline-start
MarginInlineEndmargin-inline-end
OutlineColoroutline-color
OutlineStyleoutline-style
OutlineWidthoutline-width
OutlineOffsetoutline-offset
PaddingToppadding-top
PaddingLeftpadding-left
PaddingBottompadding-bottom
PaddingRightpadding-right
PaddingBlockStartpadding-block-start
PaddingBlockEndpadding-block-end
PaddingInlineStartpadding-inline-start
PaddingInlineEndpadding-inline-end
Cursorcursor
PointerEventspointer-events
Toptop
Leftleft
Bottombottom
Rightright
OffsetBlockStartoffset-block-start
OffsetBlockEndoffset-block-end
OffsetInlineStartoffset-inline-start
OffsetInlineEndoffset-inline-end
ZIndexz-index
FlexDirectionflex-direction
FlexWrapflex-wrap
JustifyContentjustify-content
AlignContentalign-content
AlignItemsalign-items
FlexGrowflex-grow
FlexShrinkflex-shrink
AlignSelfalign-self
Orderorder
FlexBasisflex-basis
Widthwidth
MinWidthmin-width
MaxWidthmax-width
Heightheight
MinHeightmin-height
MaxHeightmax-height
BlockSizeblock-size
MinBlockSizemin-block-size
MaxBlockSizemax-block-size
InlineSizeinline-size
MinInlineSizemin-inline-size
MaxInlineSizemax-inline-size
BoxSizingbox-sizing
TableLayouttable-layout
TextOverflowtext-overflow
UnicodeBidiunicode-bidi
TextDecorationLinetext-decoration-line
Methods
impl LonghandId[src]
pub fn name(&self) -> &'static str[src]
Get the name of this longhand property.
pub fn is_animatable(self) -> bool[src]
Returns whether this property is animatable.
pub fn is_discrete_animatable(self) -> bool[src]
Returns whether this property is animatable in a discrete way.
pub fn to_physical(&self, wm: WritingMode) -> Self[src]
If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.
pub fn flags(&self) -> PropertyFlags[src]
Returns PropertyFlags for given longhand property.
pub fn stores_complex_colors_lossily(&self) -> bool[src]
Whether computed values of this property lossily convert any complex colors into RGBA colors.
In Gecko, there are some properties still that compute currentcolor
down to an RGBA color at computed value time, instead of as
StyleComplexColors. For these properties, we must return false,
so that we correctly avoid caching style data in the rule tree.