Enum style::properties::PropertyDeclarationId
[−]
[src]
pub enum PropertyDeclarationId<'a> {
Longhand(LonghandId),
Custom(&'a Name),
}An identifier for a given property declaration, which can be either a longhand or a custom property.
Variants
Longhand(LonghandId)A longhand.
Custom(&'a Name)A custom property declaration.
Methods
impl<'a> PropertyDeclarationId<'a>[src]
pub fn is_or_is_longhand_of(&self, other: &PropertyId) -> bool[src]
Whether a given declaration id is either the same as other, or a
longhand of it.
pub fn is_longhand_of(&self, shorthand: ShorthandId) -> bool[src]
Whether a given declaration id is a longhand belonging to this shorthand.
pub fn name(&self) -> Cow<'static, str>[src]
Returns the name of the property without CSS escaping.