Enum style::properties::ShorthandId
[−]
[src]
pub enum ShorthandId {
Background,
BackgroundPosition,
BorderColor,
BorderStyle,
BorderWidth,
BorderTop,
BorderLeft,
BorderBottom,
BorderRight,
BorderBlockStart,
BorderBlockEnd,
BorderInlineStart,
BorderInlineEnd,
Border,
BorderRadius,
BorderImage,
Overflow,
Transition,
Animation,
Columns,
Font,
FontVariant,
ListStyle,
Margin,
Outline,
Padding,
FlexFlow,
Flex,
TextDecoration,
All,
}An identifier for a given shorthand property.
Variants
Backgroundbackground
BackgroundPositionbackground-position
BorderColorborder-color
BorderStyleborder-style
BorderWidthborder-width
BorderTopborder-top
BorderLeftborder-left
BorderBottomborder-bottom
BorderRightborder-right
BorderBlockStartborder-block-start
BorderBlockEndborder-block-end
BorderInlineStartborder-inline-start
BorderInlineEndborder-inline-end
Borderborder
BorderRadiusborder-radius
BorderImageborder-image
Overflowoverflow
Transitiontransition
Animationanimation
Columnscolumns
Fontfont
FontVariantfont-variant
ListStylelist-style
Marginmargin
Outlineoutline
Paddingpadding
FlexFlowflex-flow
Flexflex
TextDecorationtext-decoration
Allall
Methods
impl ShorthandId[src]
pub fn name(&self) -> &'static str[src]
Get the name for this shorthand property.
pub fn longhands(&self) -> &'static [LonghandId][src]
Get the longhand ids that form this shorthand.
pub fn longhands_to_css<'a, W, I>(
&self,
declarations: I,
dest: &mut W
) -> Result where
W: Write,
I: Iterator<Item = &'a PropertyDeclaration>, [src]
&self,
declarations: I,
dest: &mut W
) -> Result where
W: Write,
I: Iterator<Item = &'a PropertyDeclaration>,
Try to serialize the given declarations as this shorthand.
Returns an error if writing to the stream fails, or if the declarations do not map to a shorthand.
pub fn get_shorthand_appendable_value<'a, I>(
self,
declarations: I
) -> Option<AppendableValue<'a, I::IntoIter>> where
I: IntoIterator<Item = &'a PropertyDeclaration>,
I::IntoIter: Clone, [src]
self,
declarations: I
) -> Option<AppendableValue<'a, I::IntoIter>> where
I: IntoIterator<Item = &'a PropertyDeclaration>,
I::IntoIter: Clone,
Finds and returns an appendable value for the given declarations.
Returns the optional appendable value.
pub fn flags(&self) -> PropertyFlags[src]
Returns PropertyFlags for given shorthand property.