Struct style::properties::PropertyFlags
[−]
pub struct PropertyFlags { /* fields omitted */ }A set of flags for properties.
Methods
impl PropertyFlags
pub const CREATES_STACKING_CONTEXT: PropertyFlags
CREATES_STACKING_CONTEXT: PropertyFlags = PropertyFlags{bits: 1 << 0,}
This property requires a stacking context.
pub const FIXPOS_CB: PropertyFlags
FIXPOS_CB: PropertyFlags = PropertyFlags{bits: 1 << 1,}
This property has values that can establish a containing block for fixed positioned and absolutely positioned elements.
pub const ABSPOS_CB: PropertyFlags
ABSPOS_CB: PropertyFlags = PropertyFlags{bits: 1 << 2,}
This property has values that can establish a containing block for absolutely positioned elements.
pub const SHORTHAND_ALIAS_PROPERTY: PropertyFlags
SHORTHAND_ALIAS_PROPERTY: PropertyFlags = PropertyFlags{bits: 1 << 3,}
This shorthand property is an alias of another property.
pub const APPLIES_TO_FIRST_LETTER: PropertyFlags
APPLIES_TO_FIRST_LETTER: PropertyFlags = PropertyFlags{bits: 1 << 4,}
This longhand property applies to ::first-letter.
pub const APPLIES_TO_FIRST_LINE: PropertyFlags
APPLIES_TO_FIRST_LINE: PropertyFlags = PropertyFlags{bits: 1 << 5,}
This longhand property applies to ::first-line.
pub const APPLIES_TO_PLACEHOLDER: PropertyFlags
APPLIES_TO_PLACEHOLDER: PropertyFlags = PropertyFlags{bits: 1 << 6,}
This longhand property applies to ::placeholder.
pub fn empty() -> PropertyFlags
Returns an empty set of flags.
pub fn all() -> PropertyFlags
Returns the set containing all flags.
pub fn bits(&self) -> u8
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u8) -> Option<PropertyFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u8) -> PropertyFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
Returns true if all flags are currently set.
pub fn intersects(&self, other: PropertyFlags) -> bool
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: PropertyFlags) -> bool
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: PropertyFlags)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: PropertyFlags)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: PropertyFlags)
Toggles the specified flags in-place.
pub fn set(&mut self, other: PropertyFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.